pub enum PosEdit {
Insert {
pos: usize,
content: PosContent,
},
Delete {
from: usize,
to: usize,
},
Replace {
from: usize,
to: usize,
content: PosContent,
},
AddMark {
from: usize,
to: usize,
mark: Mark,
},
RemoveMark {
from: usize,
to: usize,
mark_type: String,
},
SetBlockAttrs {
pos: usize,
attrs: Map<String, Value>,
},
}Expand description
A single position-addressed edit. Offsets are flat ProseMirror positions.
Variants
Insert
Insert content at pos.
Delete
Delete the flat range [from, to).
Replace
Replace the flat range [from, to) with content.
Fields

content: PosContentReplacement content.
AddMark
Add mark to text in the flat range [from, to).
Fields
RemoveMark
Remove every mark of mark_type from text in [from, to).
Fields
SetBlockAttrs
Replace the whole attribute map of the block at (or containing) pos.