pub enum ViolationKind {
MissingNodeType,
UnknownNodeType(String),
DisallowedChild {
parent: String,
child: String,
},
InvalidContent {
parent: String,
expr: String,
},
UnknownMark(String),
DisallowedMark {
node: String,
mark: String,
},
MissingAttr {
key: String,
},
UnknownAttr {
key: String,
},
}Expand description
The kinds of schema violation.
Variants
MissingNodeType
A node had no type.
UnknownNodeType(String)
A node’s type is not in the schema.
DisallowedChild
A child type is not allowed under its parent.
InvalidContent
A node’s children don’t satisfy its content expression.
UnknownMark(String)
A mark type is not in the schema.
DisallowedMark
A mark is registered but not allowed on this node type.
MissingAttr
A required attribute is missing (on a node, or a mark of the node).
UnknownAttr
An attribute key is not in the allowed set.